//=================================================================
//
//  Simple library to access the AD8318 ADC with an Arduino. 
//
//	See https://github.com/dl2sba/AD8318
//
//	Version 1.7.2
//
//  (c) Dietmar Krause, DL2SBA 2017
//
//  License see https://creativecommons.org/licenses/by/4.0/

#include <arduino.h>
#include <EEPROM.h>
#include <avr/pgmspace.h>
#include "AD8318.h"


AD8318::AD8318 ( void ) {
	mK0 = 2.804742194E1;
	mK1 = -3.432439417E-2;
	mK2 = 5.570579072E-6;
	mK3 = -1.015882955E-9;
	mOffset = 0;
}

/**
 *  
 */
void AD8318::readPROGMEM( uint16_t pK0 ) {
	mK0 = pgm_read_float_near(pK0 + 0 * sizeof mK0);
	mK1 = pgm_read_float_near(pK0 + 1 * sizeof mK0);
	mK2 = pgm_read_float_near(pK0 + 2 * sizeof mK0);
	mK3 = pgm_read_float_near(pK0 + 3 * sizeof mK0);
}

/**
 *  
 */
void AD8318::readEEPROM( uint16_t pEEPROMOffset ) {
	EEPROM.get(pEEPROMOffset + 0 * sizeof mK0, mK0);
	EEPROM.get(pEEPROMOffset + 1 * sizeof mK0, mK1);
	EEPROM.get(pEEPROMOffset + 2 * sizeof mK0, mK2);
	EEPROM.get(pEEPROMOffset + 3 * sizeof mK0, mK3);
}

float AD8318::toPower(uint16_t x) {
	return (mK0 + mK1 * x + mK2 * x * x + mK3 * x * x * x) - mOffset;
}
